Phase

Enum Phase 

pub enum Phase {
    Connecting,
    Syncing {
        at: u64,
        target: u64,
    },
    Ready,
}
Bootstrap progress of the chain.

Variants



Connecting

The chain has been added and no block is being streamed yet.



Syncing

A GrandPa warp sync is in progress.

Fields

at: u64

Highest block proven finalized by the warp sync fragments verified so far.

target: u64

Highest best block advertised by a connected peer. Never below at.



Ready

The sync service is streaming new blocks. Not terminal: a later warp sync moves the chain back to Phase::Syncing, then to Ready again.